ScanResult class

Constructors

ScanResult({String data = '', String labelType = '', String source = ''})
ScanResult.fromEventPayload(JsonMap jsonMap)
factory

Properties

data ↔ String
getter/setter pair
dateTime ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labelType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited