ScannerStatus class

Constructors

ScannerStatus({required String status, required String profile})
ScannerStatus.fromEventPayload(JsonMap jsonMap)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
profile ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ScannerStatusType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited